import 'dart:convert';
import 'package:http/http.dart' as http;

import '../models/counts_by_day.dart';
import '../models/counts_by_hour.dart';
import '../models/statistics.dart';
import '../models/timeline.dart';

class ScrobblesApi {
  static String baseUrl = 'https://scrobble.harrault.fr';

  static Future<StatisticsData> fetchStatistics() async {
    final response = await http.get(Uri.parse(baseUrl + '/stats'));

    if (response.statusCode == 200) {
      return StatisticsData.fromJson(jsonDecode(response.body) as Map<String, dynamic>);
    } else {
      throw Exception('Failed to get data from API.');
    }
  }

  static Future<TimelineData> fetchTimeline(int daysCount) async {
    final String url = baseUrl + '/data/' + daysCount.toString() + '/timeline';
    final response = await http.get(Uri.parse(url));

    if (response.statusCode == 200) {
      return TimelineData.fromJson(jsonDecode(response.body) as Map<String, dynamic>);
    } else {
      throw Exception('Failed to get data from API.');
    }
  }

  static Future<CountsByDayData> fetchCountsByDay(int daysCount) async {
    final String url = baseUrl + '/data/' + daysCount.toString() + '/counts-by-day';
    final response = await http.get(Uri.parse(url));

    if (response.statusCode == 200) {
      return CountsByDayData.fromJson(jsonDecode(response.body) as Map<String, dynamic>);
    } else {
      throw Exception('Failed to get data from API.');
    }
  }

  static Future<CountsByHourData> fetchCountsByHour(int daysCount) async {
    final String url = baseUrl + '/data/' + daysCount.toString() + '/counts-by-hour';
    final response = await http.get(Uri.parse(url));

    if (response.statusCode == 200) {
      return CountsByHourData.fromJson(jsonDecode(response.body) as Map<String, dynamic>);
    } else {
      throw Exception('Failed to get data from API.');
    }
  }
}
